def chatCompletion(llm, sampling_params, messages, response_format=None):
    query = '<|begin_of_text|>'
    for message in messages[:-1]:
        query += f'<|start_header_id|>{message["role"]}<|end_header_id|>{message["content"]}<|eot_id|>\n'
    if response_format:
        query += f'<|start_header_id|>{messages[-1]["role"]}<|end_header_id|>{messages[-1]["content"]}\nRespond in this format with no additional output, text, or formatting: {response_format}\n<|eot_id|>\n'
    else:
        query += f'<|start_header_id|>{messages[-1]["role"]}<|end_header_id|>{message[-1]["content"]}<|eot_id|>\n'
    query += '<|start_header_id|>assistant<|end_header_id|>\n'

    output = llm.generate([query], sampling_params)[0]
    return output


from setuptools import setup, find_packages

setup(
    name="caai_vllm_tools",  # Package name
    version="0.1.1",  # Initial version
    author="valogan",
    author_email="vaiden.logan@yahoo.com",
    description="A tool that allows you to use the OpenAI API with vLLM generate function",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/my_package",  # Repository URL
    packages=find_packages(),
    install_requires=[
        "vllm>=0.6.3.post1"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
)
